[seam-commits] Seam SVN: r13829 - in branches/community/Seam_2_2: ui/src/main/config/component and 1 other directory.

seam-commits at lists.jboss.org seam-commits at lists.jboss.org
Tue Oct 12 07:33:52 EDT 2010


Author: manaRH
Date: 2010-10-12 07:33:52 -0400 (Tue, 12 Oct 2010)
New Revision: 13829

Modified:
   branches/community/Seam_2_2/src/main/org/jboss/seam/core/ConversationPropagation.java
   branches/community/Seam_2_2/src/main/org/jboss/seam/core/Manager.java
   branches/community/Seam_2_2/src/main/org/jboss/seam/core/PropagationType.java
   branches/community/Seam_2_2/ui/src/main/config/component/conversationPropagation.xml
Log:
JBSEAM-4284

Modified: branches/community/Seam_2_2/src/main/org/jboss/seam/core/ConversationPropagation.java
===================================================================
--- branches/community/Seam_2_2/src/main/org/jboss/seam/core/ConversationPropagation.java	2010-10-11 14:02:40 UTC (rev 13828)
+++ branches/community/Seam_2_2/src/main/org/jboss/seam/core/ConversationPropagation.java	2010-10-12 11:33:52 UTC (rev 13829)
@@ -33,7 +33,7 @@
    private static final LogProvider log = Logging.getLogProvider(ConversationPropagation.class);
 
    public static final String CONVERSATION_NAME_PARAMETER = "conversationName";
-   public static final String CONVERSATION_PROPAGATION_PARAMETER = "conversationPropagation";
+   public static final String CONVERSATION_PROPAGATION_PARAMETER = " ";
    
    private String conversationName;
    private String conversationId;
@@ -160,7 +160,7 @@
       if (value.startsWith("begin"))
       {
          propagationType = PropagationType.BEGIN;
-         if ( value.length()>6 )
+         if ( value.length() > 6 )
          {
             pageflow = value.substring(6);
          }         
@@ -168,17 +168,17 @@
       else if (value.startsWith("join"))
       {
          propagationType = PropagationType.JOIN;
-         if ( value.length()>5 )
+         if ( value.length() > 5 )
          {
             pageflow = value.substring(5);
          }         
       }
-      else if (value.startsWith("nest"))
+      else if (value.startsWith("nested"))
       {
-         propagationType = PropagationType.NEST;
-         if ( value.length()>5 )
+         propagationType = PropagationType.NESTED;
+         if ( value.length() > 7 )
          {
-            pageflow = value.substring(5);
+            pageflow = value.substring(7);
          }         
       }
       else

Modified: branches/community/Seam_2_2/src/main/org/jboss/seam/core/Manager.java
===================================================================
--- branches/community/Seam_2_2/src/main/org/jboss/seam/core/PropagationType.java	2010-10-11 14:02:40 UTC (rev 13828)
+++ branches/community/Seam_2_2/src/main/org/jboss/seam/core/PropagationType.java	2010-10-12 11:33:52 UTC (rev 13829)
@@ -9,7 +9,7 @@
 {
    BEGIN,
    JOIN,
-   NEST,
+   NESTED,
    NONE,
    END,
    ENDROOT

Modified: branches/community/Seam_2_2/ui/src/main/config/component/conversationPropagation.xml
===================================================================
--- branches/community/Seam_2_2/ui/src/main/config/component/conversationPropagation.xml	2010-10-11 14:02:40 UTC (rev 13828)
+++ branches/community/Seam_2_2/ui/src/main/config/component/conversationPropagation.xml	2010-10-12 11:33:52 UTC (rev 13829)
@@ -34,7 +34,7 @@
 		<property>
 			<name>type</name>
 			<classname>java.lang.String</classname>
-			<description>determines the conversation propagation style: begin, join, nest, none, end or endRoot.</description>
+			<description>determines the conversation propagation style: begin, join, nested, none, end or endRoot.</description>
 			<defaultvalue>"none"</defaultvalue>
 		</property>
 	</component>



More information about the seam-commits mailing list
--- branches/community/Seam_2_2/src/main/org/jboss/seam/core/Manager.java	2010-10-11 14:02:40 UTC (rev 13828)
+++ branches/community/Seam_2_2/src/main/org/jboss/seam/core/Manager.java	2010-10-12 11:33:52 UTC (rev 13829)
@@ -514,7 +514,7 @@
 
    /**
     * Look for a conversation propagation style in the request
     * parameters and begin, nest or join the conversation,
     * as necessary.
     * 
     * @param parameters the request parameters
@@ -553,7 +553,7 @@
                }
             }
             break;
-         case NEST:
+         case NESTED:
             if ( isLongRunningOrNestedConversation() ) 
             {
                 beginNestedConversation();
@@ -514,7 +514,7 @@
    /**
     * Look for a conversation propagation style in the request
-    * parameters and begin, nest or join the conversation,
+    * parameters and begin, nested or join the conversation,
     * as necessary.
     * 

Modified: branches/community/Seam_2_2/src/main/org/jboss/seam/core/PropagationType.java
===================================================================